@@ -14,7 +14,7 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.433';
+our $VERSION = '2017.444';
 
 &saveToS3('DataTableText') if 0;                                                # Save code
 
@@ -59,19 +59,15 @@ sub fileModTime($)
 # Check whether a target is out of date relative to an array of files.
 #-------------------------------------------------------------------------------
 
-=pod
-
-Used when one file is dependent on many files to make sure that the target is
-younger than all its sources. Allows for an easy test of the form:
-
-if (fileOutOfDate($target, $source1,$source2,$source3))
-
-as in 'make' to decide whether the target needs to be updated from its sources.
-
-Returns the first out of date source file to make debugging easier, or undef if
-no files are out of date.
-
-=cut
+# Used when one file is dependent on many files to make sure that the target is
+# younger than all its sources. Allows for an easy test of the form:
+#
+# if (fileOutOfDate($target, $source1,$source2,$source3))
+#
+# as in 'make' to decide whether the target needs to be updated from its sources.
+#
+# Returns the first out of date source file to make debugging easier, or undef if
+# no files are out of date.
 
 sub fileOutOfDate($@)
  {my ($target, @sources) = @_;                                                  # Target, sources
@@ -193,7 +189,8 @@ sub readFile($)
  {my ($file) = @_;
   my $f = $file;
   -e $f or confess "Cannot read file $f because it does not exist";
-  open(my $F, "<:encoding(UTF-8)", $f) or confess "Cannot open $f for unicode input";
+  open(my $F, "<:encoding(UTF-8)", $f) or confess
+    "Cannot open $f for unicode input";
   local $/ = undef;
   my $s = eval {<$F>};
   $@ and confess $@;
@@ -283,7 +280,8 @@ sub imageSize($)
 
 sub convertImageToJpx($$$)                                                      # Convert an image to jpx format
  {my ($source, $target, $size) = @_;                                            # Source file, target folder (as multiple files will be created),  size of each tile
-  -e $source or confess "convertImageJpx: cannot convert image file $source, as file does not exist";
+  -e $source or confess
+   "convertImageJpx: cannot convert image file $source, as file does not exist";
   makePath($target);
   my ($w, $h) = imageSize($source);
   writeFile(filePath($target, "jpx.data"), <<END);
@@ -618,7 +616,7 @@ sub containingPowerOfTwo($)
 #-------------------------------------------------------------------------------
 
 sub javaPackage($)
- {my ($javaFile) = @_;                                                                 # Number to check
+ {my ($javaFile) = @_;                                                          # Java file
   my $s = readFile($javaFile);
   my ($p) = $s =~ m(package\s+(\S+)\s*;);
   $p
@@ -828,7 +826,7 @@ http://www.appaapps.com
 
 =head1 Copyright
 
-Copyright (c) 2016 Philip R Brenan.
+Copyright (c) 2016-2017 Philip R Brenan.
 
 This module is free software. It may be used, redistributed and/or
 modified under the same terms as Perl itself.
